.. _routines.dtype:

Data type routines
==================

.. currentmodule:: numpy

.. autosummary::
   :toctree: generated/

   can_cast
   promote_types
   min_scalar_type
   result_type
   common_type
   obj2sctype

Creating data types
-------------------

.. autosummary::
   :toctree: generated/


   dtype
   format_parser

Data type information
---------------------
.. autosummary::
   :toctree: generated/

   finfo
   iinfo
   MachAr

Data type testing
-----------------
.. autosummary::
   :toctree: generated/

   issctype
   issubdtype
   issubsctype
   issubclass_
   find_common_type

Miscellaneous
-------------
.. autosummary::
   :toctree: generated/

   typename
   sctype2char
   mintypecode
